; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

;-|CPU Commands|-----------------------------------------------------------
[Command]
name = "CPU1"
command = D,D,U,U,D,U
time = 1

[Command]
name = "CPU2"
command = x,y,U,x,x,x
time = 1

[Command]
name = "CPU3"
command = y,y,y,U,D,D
time = 1

[Command]
name = "CPU4"
command = U,U,U,U,D,U
time = 1

[Command]
name = "CPU5"
command = D,D,D,U,D,U
time = 1

[Command]
name = "CPU6"
command = D,D,D,U,D,D
time = 1

[Command]
name = "CPU7"
command = D,U,U,U,U,U
time = 1

[Command]
name = "CPU8"
command = D,D,D,D,D,U
time = 1

[Command]
name = "CPU9"
command = D,D,U,x,D,U
time = 1

[Command]
name = "CPU10"
command = D,D,U,y,D,U
time = 1

[Command]
name = "CPU11"
command = D,x,y,U,D,U
time = 1

[Command]
name = "CPU12"
command = x,a,b,x,x,x
time = 1

[Command]
name = "CPU13"
command = y,y,y,x,a,D
time = 1

[Command]
name = "CPU14"
command = U,a,c,U,D,U
time = 1

[Command]
name = "CPU15"
command = c,c,D,U,D,U
time = 1

[Command]
name = "CPU16"
command = b,b,D,U,D,D
time = 1

[Command]
name = "CPU17"
command = x,y,c,a,U,U
time = 1

[Command]
name = "CPU18"
command = a,a,y,D,D,U
time = 1

[Command]
name = "CPU19"
command = z,D,a,x,D,y
time = 1

[Command]
name = "CPU20"
command = c,a,b,y,D,x
time = 1

[Command]
name = "CPU21"
command = D,D,x,x,x,x
time = 1

[Command]
name = "CPU22"
command = x,y,U,y,y,y
time = 1

[Command]
name = "CPU23"
command = y,D,c,U,D,D
time = 1

[Command]
name = "CPU24"
command = b,b,b,b,D,U
time = 1

[Command]
name = "CPU25"
command = b,c,c,c,D,U
time = 1

[Command]
name = "CPU26"
command = a,b,c,x,y,z
time = 1

[Command]
name = "CPU27"
command = z,y,x,c,b,a
time = 1

[Command]
name = "CPU28"
command = x,D,y,D,z,U
time = 1

[Command]
name = "CPU29"
command = a,D,b,x,c,U
time = 1

[Command]
name = "CPU30"
command = a,D,z,y,z,U
time = 1

[Command]
name = "CPU31"
command = U,c,D,c,D,U
time = 1

[Command]
name = "CPU32"
command = c,c,b,c,x,x
time = 1

[Command]
name = "CPU33"
command = b,b,a,U,a,D
time = 1

[Command]
name = "CPU34"
command = U,a,x,y,y,y
time = 1

[Command]
name = "CPU35"
command = c,c,z,z,z,z
time = 1

[Command]
name = "CPU36"
command = U,U,U,U,c,c
time = 1

[Command]
name = "CPU37"
command = c,x,U,a,U,U
time = 1

[Command]
name = "CPU38"
command = D,a,y,D,a,y
time = 1

[Command]
name = "CPU39"
command = c,D,a,y,D,a
time = 1

[Command]
name = "CPU40"
command = b,a,b,y,U,U
time = 1

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_z"
command = ~F, D, DF, z

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command] ;Half circle back + a
name = "HCB_2p"
command = ~F, DF, D, DB, B, x+y

[Command] ;Half circle back + a
name = "HCB_2p"
command = ~F, DF, D, DB, B, y+z

[Command] ;Half circle back + a
name = "HCB_2p"
command = ~F, DF, D, DB, B, z+x

[Command]
name = "QCF_a"
command = ~D, DF, F, a
time = 15

[Command]
name = "QCF_b"
command = ~D, DF, F, b
time = 15

[Command]
name = "QCF_c"
command = ~D, DF, F, c
time = 15

[Command]
name = "QCB_x"
command = ~D, DB, B, x
time = 15

[Command]
name = "QCB_y"
command = ~D, DB, B, y
time = 15

[Command]
name = "QCB_z"
command = ~D, DB, B, z
time = 15

[Command]
name = "QCF_x"
command = ~D, DF, F, x
time = 15

[Command]
name = "QCF_y"
command = ~D, DF, F, y
time = 15

[Command]
name = "QCF_z"
command = ~D, DF, F, z
time = 15

;[Command]
;name = "QCF_xy"
;command = ~D, DF, F, x+y

[Command]
name = "QCB_a"
command = ~D, DB, B, a
time = 15

[Command]
name = "QCB_b"
command = ~D, DB, B, b
time = 15

[Command]
name = "QCB_c"
command = ~D, DB, B, c
time = 15

[Command]
name = "QCF_2k"
command = ~D, DF, F, a+b

[Command]
name = "QCF_2k"
command = ~D, DF, F, a+c

[Command]
name = "QCF_2k"
command = ~D, DF, F, b+c

[Command]
name = "QCB_2k"
command = ~D, DB, B, a+b

[Command]
name = "QCF_2p"
command = ~D, DF, F, x+y

[Command]
name = "QCF_2p"
command = ~D, DF, F, x+z

[Command]
name = "QCF_2p"
command = ~D, DF, F, y+z

[Command]
name = "QCB_2p"
command = ~D, DB, B, x+y

[Command]
name = "QCB_2p"
command = ~D, DB, B, x+z

[Command]
name = "QCB_2p"
command = ~D, DB, B, y+z


[Command]
name = "qcb_2k"
command = ~D, DB, B, a+b

[Command]
name = "qcb_2k"
command = ~D, DB, B, a+c

[Command]
name = "qcb_2k"
command = ~D, DB, B, b+c

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

[Command]
name = "pushback"
command = y+b

[Command]
name = "launcher"
command = x+a

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "FWD_y"
command = /$F,y
time = 1

[Command]
name = "FWD_z"
command = /$F,z
time = 1

[Command]
name = "FWD_b"
command = /$F,b
time = 1

[Command]
name = "FWD_c"
command = /$F,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "counter"
command = /$B, x + a
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "DU"
command = D, U
time = 15

[Command]
name = "DU"
command = D, UB
time = 15

[Command]
name = "DU"
command = D, UF
time = 15

[Command]
name = "airfollow"
command = U

[Command]
name = "airfollow"
command = UF

[Command]
name = "airfollow" ;Required (do not remove)
command = /$U
time = 1


;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "CPU1"
command = D, D, U, U, D, U
time = 1

[Command]
name = "CPU2"
command = D, F, D, F, F, D, F
time = 1

[Command]
name = "CPU3"
command = B, D, F, B, B, D
time = 1

[Command]
name = "CPU4"
command = D, D, U, U, D, U, F, U
time = 1

[Command]
name = "CPU5"
command = D, F, D, F, F, D, F, U, U
time = 1

[Command]
name = "CPU6"
command = B, D, F, B, B, D, U
time = 1

[Command]
name = "CPU7"
command = B, F, B, F, F, D, F, U, U, U
time = 1

[Command]
name = "CPU8"
command = B, F, F, B, F, D, U, U
time = 1

[Command]
name = "CPU9"
command = D, F, D, F, F, D, F, U, U, F, U, U, B
time = 1

[Command]
name = "CPU10"
command = B, D, F, B, B, B, B
time = 1

[Command]
name = "CPU11"
command = D, F, D, F, F, D, F, U, U, B, B, U, F
time = 1

[Command]
name = "CPU12"
command = B, D, D, B, B, D, U, U, U, F
time = 1

[Command]
name = "CPU13"
command = D, F, D, F, F, D, F, U, B, B, B, U
time = 1

[Command]
name = "CPU14"
command = B, D, F, B, B, D, F, U, B, F, U
time = 1

[Command]
name = "Hyper1"
command = F, F, D, D, F, B
time = 1

[Command]
name = "Hyper2"
command = F, B, F, D, F, F, F, B
time = 1

[Command]
name = "Hyper3"
command = F, B, F, D, F, F, F, B, F, B
time = 1

[Command]
name = "Hyper4"
command = F, B, F, D, F, F, F, B
time = 1

[Command]
name = "Hyper5"
command = F, B, F, D, F, F, F, B, F, B, D, F, D
time = 1

[Command]
name = "Hyper6"
command = F, B, F, D, F, F, F, B, D, D
time = 1

[Command]
name = "Hyper7"
command = F, B, F, D, F, F, F, B, F, B, F
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------

;===========================================================================
;---------------------------------------------------------------------------

[State -1, SetAIVar]
type = varset
v = 58
value = 1
triggerall = var(58) = 0
trigger1 = (command = "CPU1") && const(data.sparkno) != 0
trigger2 = (command = "CPU2") && const(data.sparkno) != 0
trigger3 = (command = "CPU3") && const(data.sparkno) != 0
trigger4 = (command = "CPU4") && const(data.sparkno) != 0
trigger5 = (command = "CPU5") && const(data.sparkno) != 0
trigger6 = (command = "CPU6") && const(data.sparkno) != 0
trigger7 = (command = "Hyper1") && const(data.sparkno) != 0
trigger8 = (command = "Hyper2") && const(data.sparkno) != 0
trigger9 = (command = "Hyper3") && const(data.sparkno) != 0
trigger10 = (command = "Hyper4") && const(data.sparkno) != 0
trigger11 = (command = "Hyper5") && const(data.sparkno) != 0
trigger12 = (command = "Hyper6") && const(data.sparkno) != 0
trigger13 = (command = "Hyper7") && const(data.sparkno) != 0
trigger14 = (command = "CPU7") && const(data.sparkno) != 0
trigger15 = (command = "CPU8") && const(data.sparkno) != 0
trigger16 = (command = "CPU9") && const(data.sparkno) != 0
trigger17 = (command = "CPU10") && const(data.sparkno) != 0
trigger18 = (command = "CPU11") && const(data.sparkno) != 0
trigger19 = (command = "CPU12") && const(data.sparkno) != 0
trigger20 = (command = "CPU13") && const(data.sparkno) != 0
trigger21 = (command = "CPU14") && const(data.sparkno) != 0

;Ground Counter
;[State -1, GroundCounter]
;type = ChangeState
;value = 900
;triggerall = stateno = 150 || stateno = 151
;trigger1 = (command = "counter") && (Statetype != A) && (power >= 1000)
;trigger2 = var(58) = 1 && (random >= 990) && (power >= 1000)

;Air Counter
;[State -1, AirCounter]
;type = ChangeState
;value = 901
;triggerall = stateno = 154
;trigger1 = (command = "counter") && (Statetype = A) && (power >= 1000)
;trigger2 = var(58) = 1 && (random >= 990) && (power >= 1000)

;Dash Forward
[State -1, Dash Forward]
type = ChangeState
value = 161
triggerall = (Statetype != A) && (ctrl) && (stateno != 161)
trigger1 = (command = "FF") && (var(58) = 0)
trigger2 = (var(58) = 1) && (P2BodyDist X = [200, 400]) && (random > 900)

;AI
[State -1,AI Combo]
type = ChangeState
value = 3501
triggerall = (var(58) = 1) && (P2BodyDist X = [0, 50]) && ctrl
trigger1 = (P2BodyDist y = [-10, 10]) && var(36) = 0 && (random > 500) && p2life > 0

;Dash Backward
[State -1, Dash Backward]
type = ChangeState
value = 162
triggerall = (Statetype != A) && (ctrl)
trigger1 = (command = "BB") && (var(58) = 0)
trigger2 = (command = "BB") && (var(58) = 1) && (P2BodyDist X = [0, 100]) && (backedgedist > 200)

;Super Jump
[State -1, Super Jump]
type = ChangeState
value = 41
triggerall = (Statetype != A) && (ctrl)
trigger1 = (command = "DU") ;&& (var(20) = 0)

;Throw
[State -1, Grab And Throw]
type = ChangeState
value = 3002
triggerall = stateno != 3900
triggerall = (Statetype = S) && (ctrl) && p2statetype != L
triggerall = command != "QCF_y"
triggerall = command != "QCF_z"
triggerall = command != "upper_y"
triggerall = command != "upper_z"
trigger1 = (command = "FWD_y") && (P2BodyDist X = [0, 10])
trigger2 = (command = "FWD_z") && var(35) != 3002 && var(36) = 0 && (P2BodyDist X = [0, 10])

;Throw in Air
[State -1, Grab And Throw in the Air]
type = ChangeState
value = 30021
triggerall = stateno != 3900
triggerall = enemy, pos y < -5
;triggerall = p2statetype A
triggerall = p2statetype != L
triggerall = (Statetype = A) && (ctrl)
triggerall = command != "QCF_y"
triggerall = command != "QCF_z"
triggerall = command != "upper_y"
triggerall = command != "upper_z"
trigger1 = (command = "FWD_y") && (P2BodyDist X = [0, 10])
trigger2 = (command = "FWD_z") && var(35) != 3002 && var(36) = 0 && (P2BodyDist X = [0, 10])

[State -1, Gliders]
type = ChangeState
value = 3700
triggerall = (Statetype = S) && (ctrl)
trigger1 = (command = "QCF_2k") && (power >= 1000)

[State -1, Siva + Lou Hyper]
type = ChangeState
value = 3750
triggerall = numhelper(951) = 0
triggerall = ctrl && statetype = S
trigger1 = (command = "QCF_2p") && (power >= 1000)

[State -1, Chariot]
type = ChangeState
value = 3900
triggerall = (Statetype = S) && (ctrl)
trigger1 = (command = "QCB_2p") && (power >= 1500)

[State -1, Taunt]
type = ChangeState
value = 938
triggerall = ctrl && (statetype = S || statetype = C)
trigger1 = (command = "start")


[State -1, Normal Shot]
type = ChangeState
value = 750
triggerall = (Statetype = S) && (ctrl)
triggerall = command != "upper_x"
trigger1 = (command = "QCF_x") ;&& (numhelper(751) = 0) ;&& (var(58) = 0) && var(59) > 0
;trigger2 = (var(58) = 1) && var(35) != 750 && var(36) = 0 && (P2BodyDist X = [50,100]) && random >= 950 && var(59) > 0 && (numhelper(751) = 0)

[State -1, Normal Shot A]
type = ChangeState
value = 7501
triggerall = stateno!= 3900
triggerall = (Statetype = A) && (ctrl)
trigger1 = (command = "QCF_x")

[State -1, Tail Shot]
type = ChangeState
value = 860
triggerall = numhelper(865) = 0
triggerall = (Statetype = S) && (ctrl)
triggerall = command != "upper_y"
trigger1 = (command = "QCF_y")

[State -1, Tail Shot A]
type = ChangeState
value = 8601
triggerall = stateno!= 3900
triggerall = numhelper(865) = 0
triggerall = (Statetype = A) && (ctrl)
trigger1 = (command = "QCF_y")

[State -1, Hyper Shot]
type = ChangeState
value = 880
triggerall = numhelper(881) = 0
triggerall = (Statetype = S) && (ctrl)
triggerall = command != "upper_z"
trigger1 = (command = "QCF_z")

[State -1, Hyper Shot A]
type = ChangeState
value = 8801
triggerall = stateno!= 3900
triggerall = numhelper(881) = 0
triggerall = (Statetype = A) && (ctrl)
trigger1 = (command = "QCF_z")

[State -1, Shoot Bazooka]
type = ChangeState
value = 850
triggerall = (Statetype = S) && (ctrl)
trigger1 = (command = "QCB_z")
trigger2 = (command = "QCB_y")
trigger3 = (command = "QCB_x")

[State -1, Siva's Knife Throw]
type = ChangeState
value = 950
triggerall = ctrl && statetype = S
trigger1 = command = "QCF_a"
trigger2 = command = "QCF_b"
trigger3 = command = "QCF_c"
  ;&& (var(58) = 0) && var(59) > 0
;trigger2 = (var(58) = 1) && (random > 995) && var(59) > 0 && var(19) <= 0

[State -1, Upperstab 1]
type = ChangeState
value = 800
triggerall = (Statetype = S) && (ctrl)
trigger1 = command = "upper_x"

[State -1, Upperstab 2]
type = ChangeState
value = 801
triggerall = (Statetype = S) && (ctrl)
trigger1 = command = "upper_y"

[State -1, Upperstab 3]
type = ChangeState
value = 802
triggerall = (Statetype = S) && (ctrl)
trigger1 = command = "upper_z"

[State -1, Upperstab 3]
type = ChangeState
value = 660
triggerall = (Statetype = A) && (ctrl)
trigger1 = command = "QCF_c"


;Recover Roll
[State -1, Roll Forward]
type = ChangeState
value = 4800
triggerall = (stateno = 5120) && life
trigger1 = var(58) = 0 && command = "holdfwd"
trigger2 = var(58) = 1 &&(P2BodyDist X = [0, 20]) && random >= 990

[State -1, Roll Back]
type = ChangeState
value = 4801
triggerall = (stateno = 5120) && life
trigger1 = var(58) = 0 && command = "holdback"  ;holdback
trigger2 = var(58) = 1 && (P2BodyDist X = [0, 20]) && random >= 990

;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall =  (statetype = S) && (ctrl)
trigger1 = command = "x" && command != "holddown" && (var(58) = 0)
trigger2 = (var(58) = 1) && var(35) != 200 && var(36) = 0 && (P2BodyDist X = [0, 30]) && (P2BodyDist y = [-30, 30]) && random >= 900

;---------------------------------------------------------------------------
;Stand Medium Punch
;p`
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall =  (statetype = S) && (ctrl)
trigger1 = (var(58) = 0) && (ctrl) && (command != "holddown") && command = "y"
trigger2 = (var(58) = 1) && var(35) != 210 && var(36) = 0 && (P2BodyDist X = [0, 40]) && (P2BodyDist y = [-40, 40]) && random >= 900

;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = (statetype = S) && (ctrl)
trigger1 = (var(58) = 0) && (command = "z") && (command != "holddown") 
trigger2 = (var(58) = 1) && var(35) != 220 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-40, 40]) && random >= 900

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = (statetype = S) && (ctrl)
trigger1 = (var(58) = 0) && command = "a" && (command != "holddown")
trigger2 = (var(58) = 1) && var(35) != 230 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-30, 30]) && random >= 900

;---------------------------------------------------------------------------
;Standing Medium Kick
;LbN
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = (statetype = S) && (ctrl)
trigger1 = command = "b" && command != "holddown" && (var(58) = 0)
trigger2 = (var(58) = 1) && var(35) != 240 && var(36) = 0 && (P2BodyDist X = [0, 40]) && (P2BodyDist y = [-50, 50]) && random >= 900

;Standing Strong Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = (statetype = S) && (ctrl)
trigger1 = command = "c" && command != "holddown" && (var(58) = 0)
trigger2 = (var(58) = 1) && var(35) != 250 && var(36) = 0 && (P2BodyDist X = [0, 100]) && (P2BodyDist y = [-50, 50]) && random >= 900

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = (statetype = C) && (ctrl)
trigger1 = command = "x" && command = "holddown" && (var(58) = 0)
trigger2 = (var(58) = 1) && var(35) != 400 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-30, 30]) && random >= 900

;---------------------------------------------------------------------------
;Crouching Medium Punch
;Ⴊ݋p`
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = (statetype = C) && (ctrl)
trigger1 = command = "y" && command = "holddown" && (var(58) = 0)
trigger2 = (var(58) = 1) && var(35) != 410 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-60, 60]) && random >= 900

[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = (statetype = C) && (ctrl)
trigger1 = command = "z" && command = "holddown"&& (var(58) = 0)
trigger2 = (var(58) = 1) && var(35) != 420 && var(36) = 0 && (P2BodyDist X = [0, 80]) && (P2BodyDist y = [-60, 60]) && random >= 900
;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = (statetype = C) && (ctrl) 
trigger1 = command = "a" && command = "holddown"&& (var(58) = 0)
trigger2 = (var(58) = 1) && var(35) != 430 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-20, 20]) && random >= 900

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching medium Kick]
type = ChangeState
value = 440
triggerall = (statetype = C) && (ctrl)
trigger1 = command = "b"  && command = "holddown" && (var(58) = 0)
trigger2 = (var(58) = 1) && var(35) != 440 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-50, 50]) && random >= 900

[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = (statetype = C) && (ctrl)
trigger1 = command = "c" && command = "holddown" && (var(58) = 0)
trigger2 = (var(58) = 1) && var(35) != 450 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-30, 30]) && random >= 900
;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = stateno != 3900
triggerall = (statetype = A) && (ctrl)
trigger1 = (var(58) = 0) && (command = "x")  
trigger2 = (var(58) = 1) && var(35) != 600 && var(36) = 0 && (P2BodyDist X = [0, 40]) && (P2BodyDist y = [-40, 40]) && random >= 900

;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = stateno != 3900
triggerall =  ctrl && statetype = A
trigger1 = var(58) = 0 && command = "y"
trigger2 = (var(58) = 1) && var(35) != 600 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-40, 40]) && random >= 900

;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = stateno != 3900
triggerall = (statetype = A) && (ctrl)
trigger1 = (var(58) = 0) && (command = "z") 
trigger2 = (var(58) = 1) && var(35) != 620 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-40, 40]) && random >= 900
;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = stateno != 3900
triggerall = ctrl && statetype = A
trigger1 = (var(58) = 0) && command = "a"
trigger2 = (var(58) = 1) && var(35) != 630 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-40, 40]) && random >= 900

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = stateno != 3900
triggerall = ctrl && statetype = A
trigger1 = (var(58) = 0) && command = "b"
trigger2 = (var(58) = 1) && var(35) != 640 && var(36) = 0 && (P2BodyDist X = [0, 50]) && (P2BodyDist y = [-40, 40]) && random >= 900

;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = stateno != 3900
triggerall = ctrl && statetype = A
trigger1 = (var(58) = 0) && command = "c"
trigger2 = (var(58) = 1) && var(35) != 650 && var(36) = 0 && (P2BodyDist X = [0, 60]) && (P2BodyDist y = [-40, 40]) && random >= 900







;------------------------------
[State -1, ACTIVATE AI]
type = VarSet
trigger1 = command = "CPU1"
trigger2 = command = "CPU2"
trigger3 = command = "CPU3"
trigger4 = command = "CPU4"
trigger5 = command = "CPU5"
trigger6 = command = "CPU6"
trigger7 = command = "CPU7"
trigger8 = command = "CPU8"
trigger9 = command = "CPU9"
trigger10 = command = "CPU10"
trigger11 = command = "CPU11"
trigger12 = command = "CPU12"
trigger13 = command = "CPU13"
trigger14 = command = "CPU14"
trigger15 = command = "CPU15"
trigger16 = command = "CPU16"
trigger17 = command = "CPU17"
trigger18 = command = "CPU18"
trigger19 = command = "CPU19"
trigger20 = command = "CPU20"
trigger21 = command = "CPU21"
trigger22 = command = "CPU22"
trigger23 = command = "CPU23"
trigger24 = command = "CPU24"
trigger25 = command = "CPU25"
trigger26 = command = "CPU26"
trigger27 = command = "CPU27"
trigger28 = command = "CPU28"
trigger29 = command = "CPU29"
trigger30 = command = "CPU30"
trigger31 = command = "CPU31"
trigger32 = command = "CPU32"
trigger33 = command = "CPU33"
trigger34 = command = "CPU34"
trigger35 = command = "CPU35"
trigger36 = command = "CPU36"
trigger37 = command = "CPU37"
trigger38 = command = "CPU38"
trigger39 = command = "CPU39"
trigger40 = command = "CPU40"
v = 20
value = 1


;Auto Blocking AI from the tutorial by K3nShiN

; ==========================
; AI Standing Guard
; ==========================
[State -1]
type = ChangeState
triggerall = var(20) = 1 ;AI trigger used
triggerall = Statetype != A ;Player is not in the air
triggerall = P2statetype != C ;Player is not crouching
triggerall = Statetype = S ;Player is currently standing
triggerall = P2Movetype = A ;Opponent is attacking
triggerall = Pos Y != [-1,-999]
triggerall = ctrl = 1
;trigger1 = random <= 800 ;triggers at 80% probability
trigger1 = 1
value = 130 ;Default standing guard state

; =============================
; AI Stand to Crouch Guard Transition
; =============================
[State -1]
type = ChangeState
triggerall = var(20) = 1
triggerall = StateType != A
triggerall = P2statetype = C
triggerall = P2Movetype = A
triggerall = Pos Y != [-1,-999]
trigger1 = stateno = 150
trigger1 = 1
value = 152

; =============================
; AI Crouching Guard
; =============================
[State -1]
type = ChangeState
triggerall = var(20) = 1
triggerall = StateType != A
triggerall = P2statetype = C
triggerall = P2Movetype = A
triggerall = Pos Y != [-1,-999]
triggerall = ctrl = 1
;trigger1 = random <= 800
trigger1 = 1
value = 131

; =============================
; AI Crouch to Stand Guard Transition
; =============================
[State -1]
type = ChangeState
triggerall = var(20) = 1
triggerall = Statetype != A
triggerall = P2statetype != C
triggerall = P2Movetype = A
trigger1 = 1
trigger1 = stateno = 152
value = 150

; =============================
; AI Aerial Guard
; =============================
[State -1]
type = ChangeState
triggerall = var(20) = 1
triggerall = Statetype = A
triggerall = P2Movetype = A
triggerall = ctrl = 1
trigger1 = 1
value = 132


;HYPER ACTIVATION... WHAT A KNUCKLEHEAD
[State -1]
type = ChangeState
triggerall = power >= 1000
triggerall = var(20) = 1
triggerall = Statetype = S
triggerall = ctrl = 1
triggerall = time >= 12
trigger1 = random <= 5
value = 3700

[State -1]
type = ChangeState
triggerall = power >= 1000
triggerall = var(20) = 1
triggerall = Statetype = S
triggerall = ctrl = 1
trigger1 = random <= 7
value = 3750

[State -1]
type = ChangeState
triggerall = power >= 1000
triggerall = var(20) = 1
triggerall = Statetype = S
triggerall = ctrl = 1
trigger1 = random <= 7
value = 3900

[State -1]
type = Projectile
triggerall = var(20) = 1
triggerall = stateno = 3900
triggerall = anim = 15900
triggerall = numprojID(19600) < 3
trigger1 = time = 30
trigger2 = time = 40
trigger2 = time = 50
trigger3 = time = 60
trigger4 = time = 70
trigger5 = time = 80
trigger6 = time = 90
trigger7 = time = 100
trigger8 = time = 110
trigger9 = time = 120
trigger10 = time = 130
trigger11 = time = 140
trigger12 = time = 150
trigger13 = time = 160
trigger14 = time = 170
trigger15 = time = 180
trigger16 = time = 190
trigger17 = time = 200
trigger18 = time = 210
trigger19 = time = 220
trigger20 = time = 230
trigger21 = time = 240
trigger22 = time = 250
trigger23 = time = 260
trigger24 = time = 270
trigger25 = time = 280
trigger26 = time = 290
projanim = 19600
projID = 19600
projpriority = 1
projheightbound = -240, 100
projedgebound = 100
projscreenbound = 100
projshadow = -1
sparkno=s30030+(random%6)
guard.sparkno = s30000
sparkxy = 40,-10
hitsound   = 5,1
guardsound = 6,0
velocity = 5
attr = S, SP
damage   = 12,2
animtype = heavy
guardflag = MA
hitflag = MAFDP
pausetime = 17,17
ground.type = Low
ground.slidetime = 25
ground.hittime  = 25
ground.velocity = -6
air.animtype = Back
air.hittime =1500
air.velocity = -4,-6
fall = ifelse(time>=180,1,0)
fall.recover = 0
air.fall = ifelse(time>=180,1,0)
down.velocity = -4,-6
down.hittime = 1500
down.bounce = 1

